<template>
	<view>
		<customer-index v-if="roleType == 1" ref="customerIndexRef"></customer-index>
		<freight-forwarder-index v-if="roleType == 2" ref="freightForwarderIndexRef"></freight-forwarder-index>
		<driver-index v-if="roleType == 3" ref="driverIndexRef"></driver-index>
		<tab-bar :current="0"></tab-bar>
	</view>
</template>

<script>
import customerIndex from '@/pages/customer-page/customer-index/customer-index.vue';
import driverIndex from '@/pages/driver-page/driver-index/driver-index.vue';
import freightForwarderIndex from '@/pages/freight-forwarder-page/freightForwarder-index/freightForwarder-index.vue';

export default {
	components: {
		customerIndex,
		driverIndex,
		freightForwarderIndex
	},
	onLoad(){
		// 开启双人通话
		wx.setEnable1v1Chat({
			enable: true,
			backgroundType: 1,
			minWindowType:2,
			success() {
				console.log('开启双人通话成功');
			},
			fail() {
				console.log('开启双人通话失败');
			},
			complete() {
				console.log('开启双人通话成功Complete');
			}
		});
	},
	data() {
		return {
			roleType: null
		};
	},
	onShow() {
		this.init();
		this.userAuthorization();
	},
	methods: {
		init() {
			this.roleType = uni.getStorageSync('roleType');
			switch (this.roleType) {
				case 1:
					console.log('customerIndexRef');
					this.$nextTick(() => {
						this.$refs.customerIndexRef.init();
					});
					break;
				case 2:
					console.log('freightForwarderIndexRef');
					this.$nextTick(() => {
						this.$refs.freightForwarderIndexRef.init();
					});
					break;
				case 3:
					console.log('driverIndexRef');
					this.$nextTick(() => {
						this.$refs.driverIndexRef.init();
					});
					break;
				default:
					break;
			}
		},
		// 要求用户授权相机/麦克风权限
		userAuthorization() {
			wx.getSetting({
				success(res) {
					// wx.startRecord();
					console.log('success');
					if (!res.authSetting['scope.record'] || !res.authSetting['scope.camera']) {
						if (!res.authSetting['scope.camera']) {
							wx.authorize({
								scope: 'scope.camera',
								success() {
									// 用户已经同意小程序使用录音功能，后续调用 wx.startRecord 接口不会弹窗询问
									console.log('授权成功');
								},
								fail() {
									console.log('授权失败');
								}
							});
						} else if (!res.authSetting['scope.record']) {
							wx.authorize({
								scope: 'scope.record',
								success() {
									// 用户已经同意小程序使用录音功能，后续调用 wx.startRecord 接口不会弹窗询问
									console.log('授权成功');
								},
								fail: () => {
									console.log('授权失败');
								}
							});
						}
					}
				},
				fail() {
					console.log('获取失败');
				}
			});
		}
	}
};
</script>

<style lang="scss" scoped></style>
